# Changelog

Notable changes between releases of the Glottolog data.


## [Unreleased]


## [3.2] - 2018-01-25

See https://github.com/clld/glottolog/pulls?q=is%3Apr+is%3Amerged for a list of
accepted changes.


## [3.1] - 2017-11-22

### References

Two new bibliographies have been contributed:
- The bibliography of the [autotyp database](https://github.com/autotyp/autotyp-data)
- Marc Tang's collection of references relating to nominal classification


### Classification

Many changes small and not-so-small. For details refer to the individual
[pull requests](https://github.com/clld/glottolog/pulls?q=is%3Apr+is%3Aclosed)


### Other

[Aggregated/merged data on language endangerment](https://github.com/clld/glottolog/pulls?q=is%3Apr+is%3Aclosed) 
has been added in `[endangerment]` sections of languoid's info files.
See [SOURCES.md](SOURCES.md) for details about the sources.


## [3.0] - 2017-03-29

### References

Bibliographical records for all linguistic books and journal articles
published by John Benjamins Publishing Company have been added.


